@@ -3,7 +3,7 @@
  *   LinuxSampler - modular, streaming capable sampler                     *
  *                                                                         *
  *   Copyright (C) 2003, 2004 by Benno Senoner and Christian Schoenebeck   *
- *   Copyright (C) 2005 - 2020 Christian Schoenebeck                       *
+ *   Copyright (C) 2005 - 2025 Christian Schoenebeck                       *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -33,7 +33,7 @@ namespace LinuxSampler {
         InitWithDefault(); // use default card
     }
 
-    AudioOutputDeviceAlsa::ParameterCard::ParameterCard(String s) throw (Exception) : DeviceCreationParameterString(s) {
+    AudioOutputDeviceAlsa::ParameterCard::ParameterCard(String s) LS_THROWS(Exception) : DeviceCreationParameterString(s) {
     }
 
     String AudioOutputDeviceAlsa::ParameterCard::Description() {
@@ -86,7 +86,7 @@ namespace LinuxSampler {
         return CardNames;
     }
 
-    void AudioOutputDeviceAlsa::ParameterCard::OnSetValue(String s) throw (Exception) {
+    void AudioOutputDeviceAlsa::ParameterCard::OnSetValue(String s) LS_THROWS(Exception) {
         // not posssible, as parameter is fix
     }
 
@@ -281,7 +281,7 @@ namespace LinuxSampler {
         InitWithDefault();
     }
 
-    AudioOutputDeviceAlsa::ParameterFragments::ParameterFragments(String s) throw (Exception) : DeviceCreationParameterInt(s) {
+    AudioOutputDeviceAlsa::ParameterFragments::ParameterFragments(String s) LS_THROWS(Exception) : DeviceCreationParameterInt(s) {
     }
 
     String AudioOutputDeviceAlsa::ParameterFragments::Description() {
@@ -378,7 +378,7 @@ namespace LinuxSampler {
         return std::vector<int>();
     }
 
-    void AudioOutputDeviceAlsa::ParameterFragments::OnSetValue(int i) throw (Exception) {
+    void AudioOutputDeviceAlsa::ParameterFragments::OnSetValue(int i) LS_THROWS(Exception) {
         // not posssible, as parameter is fix
     }
 
@@ -395,7 +395,7 @@ namespace LinuxSampler {
         InitWithDefault();
     }
 
-    AudioOutputDeviceAlsa::ParameterFragmentSize::ParameterFragmentSize(String s) throw (Exception) : DeviceCreationParameterInt(s) {
+    AudioOutputDeviceAlsa::ParameterFragmentSize::ParameterFragmentSize(String s) LS_THROWS(Exception) : DeviceCreationParameterInt(s) {
     }
 
     String AudioOutputDeviceAlsa::ParameterFragmentSize::Description() {
@@ -492,7 +492,7 @@ namespace LinuxSampler {
         return std::vector<int>();
     }
 
-    void AudioOutputDeviceAlsa::ParameterFragmentSize::OnSetValue(int i) throw (Exception) {
+    void AudioOutputDeviceAlsa::ParameterFragmentSize::OnSetValue(int i) LS_THROWS(Exception) {
         // not posssible, as parameter is fix
     }
 
@@ -652,7 +652,7 @@ namespace LinuxSampler {
      *  @returns  true if hardware supports it
      *  @throws AudioOutputException - if device cannot be accessed
      */
-    bool AudioOutputDeviceAlsa::HardwareParametersSupported(String card, uint channels, int samplerate, uint numfragments, uint fragmentsize) throw (AudioOutputException) {
+    bool AudioOutputDeviceAlsa::HardwareParametersSupported(String card, uint channels, int samplerate, uint numfragments, uint fragmentsize) LS_THROWS(AudioOutputException) {
         pcm_name = "hw:" + card;
         int err;
         if ((err = snd_pcm_open(&pcm_handle, pcm_name.c_str(), stream, SND_PCM_NONBLOCK)) < 0) {
@@ -736,7 +736,7 @@ namespace LinuxSampler {
     }
 
     String AudioOutputDeviceAlsa::Version() {
-       String s = "$Revision: 3766 $";
+       String s = "$Revision: 4166 $";
        return s.substr(11, s.size() - 13); // cut dollar signs, spaces and CVS macro keyword
     }
 
