@@ -3,7 +3,7 @@
  *   LinuxSampler - modular, streaming capable sampler                     *
  *                                                                         *
  *   Copyright (C) 2003, 2004 by Benno Senoner and Christian Schoenebeck   *
- *   Copyright (C) 2005 - 2014 Christian Schoenebeck                       *
+ *   Copyright (C) 2005 - 2025 Christian Schoenebeck                       *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -102,7 +102,7 @@ namespace LinuxSampler {
 // *************** AudioChannelJack ***************
 // *
 
-    AudioOutputDeviceJack::AudioChannelJack::AudioChannelJack(uint ChannelNr, AudioOutputDeviceJack* pDevice) throw (AudioOutputException) : AudioChannel(ChannelNr, CreateJackPort(ChannelNr, pDevice), pDevice->uiMaxSamplesPerCycle) {
+    AudioOutputDeviceJack::AudioChannelJack::AudioChannelJack(uint ChannelNr, AudioOutputDeviceJack* pDevice) LS_THROWS(AudioOutputException) : AudioChannel(ChannelNr, CreateJackPort(ChannelNr, pDevice), pDevice->uiMaxSamplesPerCycle) {
         this->pDevice   = pDevice;
         this->ChannelNr = ChannelNr;
         delete Parameters["NAME"];
@@ -114,7 +114,7 @@ namespace LinuxSampler {
         //TODO: delete JACK port
     }
 
-    float* AudioOutputDeviceJack::AudioChannelJack::CreateJackPort(uint ChannelNr, AudioOutputDeviceJack* pDevice) throw (AudioOutputException) {
+    float* AudioOutputDeviceJack::AudioChannelJack::CreateJackPort(uint ChannelNr, AudioOutputDeviceJack* pDevice) LS_THROWS(AudioOutputException) {
         String port_id = ToString(ChannelNr);
         hJackPort = jack_port_register(pDevice->hJackClient, port_id.c_str(), JACK_DEFAULT_AUDIO_TYPE, JackPortIsOutput, 0);
         if (!hJackPort) throw AudioOutputException("Jack: Cannot register Jack output port.");
@@ -136,7 +136,7 @@ namespace LinuxSampler {
         InitWithDefault(); // use default name
     }
 
-    AudioOutputDeviceJack::ParameterName::ParameterName(String s) throw (Exception) : DeviceCreationParameterString(s) {
+    AudioOutputDeviceJack::ParameterName::ParameterName(String s) LS_THROWS(Exception) : DeviceCreationParameterString(s) {
     }
 
     String AudioOutputDeviceJack::ParameterName::Description() {
@@ -163,7 +163,7 @@ namespace LinuxSampler {
         return (existingJackDevices) ? "LinuxSampler" + ToString(existingJackDevices) : "LinuxSampler";
     }
 
-    void AudioOutputDeviceJack::ParameterName::OnSetValue(String s) throw (Exception) {
+    void AudioOutputDeviceJack::ParameterName::OnSetValue(String s) LS_THROWS(Exception) {
         // not possible, as parameter is fix
     }
 
@@ -200,7 +200,7 @@ namespace LinuxSampler {
         return sampleRate;
     }
 
-    void AudioOutputDeviceJack::ParameterSampleRate::OnSetValue(int i) throw (Exception) {
+    void AudioOutputDeviceJack::ParameterSampleRate::OnSetValue(int i) LS_THROWS(Exception) {
         // nothing to do: the JACK API does currently not allow JACK clients to
         // change the sample rate
     }
@@ -317,7 +317,7 @@ namespace LinuxSampler {
     }
 
     String AudioOutputDeviceJack::Version() {
-       String s = "$Revision: 2512 $";
+       String s = "$Revision: 4167 $";
        return s.substr(11, s.size() - 13); // cut dollar signs, spaces and CVS macro keyword
     }
 
