@@ -1,6 +1,6 @@
 /***************************************************************************
  *                                                                         *
- *   Copyright (C) 2006 - 2020 Christian Schoenebeck                       *
+ *   Copyright (C) 2006 - 2025 Christian Schoenebeck                       *
  *                                                                         *
  *   This library is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -116,7 +116,7 @@ namespace LinuxSampler {
         }
     }
 
-    void MidiInstrumentMapper::AddOrReplaceEntry(int Map, midi_prog_index_t Index, entry_t Entry, bool bInBackground) throw (Exception) {
+    void MidiInstrumentMapper::AddOrReplaceEntry(int Map, midi_prog_index_t Index, entry_t Entry, bool bInBackground) LS_THROWS(Exception) {
         if (bInBackground) {
             dmsg(3,("MidiInstrumentMapper: updating mapping %d (%d,%d,%d) -> ('%s','%s',%d) with vol=%f, mode=%d in background\n",
                 Map,
@@ -282,7 +282,7 @@ namespace LinuxSampler {
         }
     }
 
-    std::map<midi_prog_index_t,MidiInstrumentMapper::entry_t> MidiInstrumentMapper::Entries(int Map) throw (Exception) {
+    std::map<midi_prog_index_t,MidiInstrumentMapper::entry_t> MidiInstrumentMapper::Entries(int Map) LS_THROWS(Exception) {
         std::map<midi_prog_index_t,entry_t> result;
 
         // copy the internal map first
@@ -358,7 +358,7 @@ namespace LinuxSampler {
         return count;
     }
 
-    int MidiInstrumentMapper::AddMap(String MapName) throw (Exception) {
+    int MidiInstrumentMapper::AddMap(String MapName) LS_THROWS(Exception) {
         int ID;
         LockGuard lock(midiMapsMutex);
 
@@ -389,7 +389,7 @@ namespace LinuxSampler {
         return ID;
     }
 
-    String MidiInstrumentMapper::MapName(int Map) throw (Exception) {
+    String MidiInstrumentMapper::MapName(int Map) LS_THROWS(Exception) {
         LockGuard lock(midiMapsMutex);
         std::map<int,MidiInstrumentMap>::iterator iterMap = midiMaps.find(Map);
         if (iterMap == midiMaps.end()) {
@@ -398,7 +398,7 @@ namespace LinuxSampler {
         return iterMap->second.name;
     }
 
-    void MidiInstrumentMapper::RenameMap(int Map, String NewName) throw (Exception) {
+    void MidiInstrumentMapper::RenameMap(int Map, String NewName) LS_THROWS(Exception) {
         {
             LockGuard lock(midiMapsMutex);
             std::map<int,MidiInstrumentMap>::iterator iterMap = midiMaps.find(Map);
