@@ -1,5 +1,5 @@
 /*
-    Copyright (C) 2010 - 2013 Christian Schoenebeck
+    Copyright (C) 2010 - 2025 Christian Schoenebeck
 */
 
 #ifndef LS_LADSPAEFFECT_H
@@ -25,11 +25,11 @@ class AudioOutputDevice;
  */
 class LadspaEffect : public Effect {
 public:
-    LadspaEffect(EffectInfo* pInfo) throw (Exception);
+    LadspaEffect(EffectInfo* pInfo) LS_THROWS(Exception);
    ~LadspaEffect();
     EffectInfo* GetEffectInfo() OVERRIDE;
     void RenderAudio(uint Samples) OVERRIDE;
-    void InitEffect(AudioOutputDevice* pDevice) throw (Exception) OVERRIDE;
+    void InitEffect(AudioOutputDevice* pDevice) LS_THROWS(Exception) OVERRIDE;
     static std::vector<EffectInfo*> AvailableEffects();
 
 private:
