@@ -4,6 +4,7 @@
  *                                                                         *
  *   Copyright (C) 2008 Anders Dahnielson <anders@dahnielson.com>          *
  *   Copyright (C) 2009 - 2016 Anders Dahnielson and Grigor Iliev          *
+ *   Copyright (C) 2014 - 2025 Christian Schoenebeck                       *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -729,8 +730,8 @@ namespace sfz
         EGNode& egnode(int x, int y);
         LFO& lfo(int x);
         
-        int   ToInt(const std::string& s) throw(LinuxSampler::Exception);
-        float ToFloat(const std::string& s) throw(LinuxSampler::Exception);
+        int   ToInt(const std::string& s) LS_THROWS(LinuxSampler::Exception);
+        float ToFloat(const std::string& s) LS_THROWS(LinuxSampler::Exception);
 
         std::string rootFile;
         int currentLine;
